@@ -55,7 +55,9 @@ void
 LogUploader::sendLogs()
 {
     IMainWindow *win = (IMainWindow *) parent ();
+    win->startLongTask (LT_LogsUpload);
 
+    bool ok = false;
     do { // Begin cleanup block (not a loop)
         AsyncTaskToken *task = new AsyncTaskToken(this);
         if (!task) {
@@ -86,7 +88,7 @@ LogUploader::sendLogs()
         QDomElement appVerTag = doc.createElement("Version");
         paramsTag.appendChild(appVerTag);
 
-        QDomText appVerText = doc.createTextNode("0.4.1584");
+        QDomText appVerText = doc.createTextNode("0.4.1593");
         appVerTag.appendChild(appVerText);
 
         QDomElement osVerTag = doc.createElement("OsVer");
@@ -113,7 +115,7 @@ LogUploader::sendLogs()
         // Post the logs to my server
         QUrl url(LOGS_SERVER "/tracker/postLogs");
         url.addQueryItem ("email", win->m_user.toAscii());
-        url.addQueryItem ("version", "0.4.1584");
+        url.addQueryItem ("version", "0.4.1593");
         QNetworkRequest req(url);
         req.setHeader (QNetworkRequest::ContentTypeHeader, POST_TEXT);
 
@@ -132,7 +134,14 @@ LogUploader::sendLogs()
         }
         connect(tracker, SIGNAL(sigDone(bool,QByteArray,QNetworkReply*,void*)),
                 this, SLOT(onLogPosted(bool,QByteArray,QNetworkReply*,void*)));
+
+        ok = true;
     } while (0); // End cleanup block (not a loop)
+
+    if (!ok) {
+        win->endLongTask ();
+        win->uiShowStatusMessage ("Failed to upload logs!", SHOW_5SEC);
+    }
 }//LogUploader::sendLogs
 
 /** Invoked when the XML document containing the logs has finished uploading
@@ -146,9 +155,16 @@ LogUploader::onLogPosted(bool success, const QByteArray & /*response*/,
     AsyncTaskToken *task = (AsyncTaskToken *) ctx;
     task->deleteLater ();
 
-    if (!success) {
+    IMainWindow *win = (IMainWindow *) parent ();
+    win->endLongTask ();
+
+    if (success) {
+        Q_DEBUG("Logs uploaded");
+        win->uiShowStatusMessage (tr("Logs uploaded!"), SHOW_3SEC);
+    } else {
         QString strR = reply->readAll ();
-        Q_WARN("Failed to post the logs") << strR;
+        Q_WARN(QString("Failed to post the logs. Response = %1").arg(strR));
+        win->uiShowStatusMessage (tr("Failed to upload the logs!"), SHOW_5SEC);
     }
 }//LogUploader::onLogPosted
 
@@ -174,7 +190,7 @@ LogUploader::reportLogin()
                            "}")
                     .arg(win->m_user)
                     .arg(lib.getOsDetails ())
-                    .arg("0.4.1584");
+                    .arg("0.4.1593");
 
     QNetworkReply *reply = m_nwMgr->post (req, json.toAscii ());
 
