@@ -29,9 +29,9 @@ Contact: yuvraaj@gmail.com
 #include "DialContext.h"
 #include "GVApi.h"
 #include "FuzzyTimer.h"
+#include "Vmail.h"
 
 #include <QtDeclarative>
-#include <phonon/MediaObject>
 
 #if MOSQUITTO_CAPABLE
 #include "MqClientThread.h"
@@ -98,14 +98,14 @@ private slots:
     //! Invoked when the user clicks the login button on QML.
     void doLogin ();
     //! Called when the GV Api completes login - with success or failure
-    void loginCompleted (AsyncTaskToken *token);
+    void loginCompleted ();
 
     //! Called when the logout button is clicked
     void doCancelLogin ();
     //! Called when the logout button is clicked
     void doLogout ();
     //! Called when the GV Api completes logoff - with success or failure
-    void logoutCompleted (AsyncTaskToken *token);
+    void logoutCompleted ();
 
     //! Invoked when the system ray is clicked
     void systray_activated (QSystemTrayIcon::ActivationReason reason);
@@ -125,7 +125,7 @@ private slots:
     //! Invoked by the context when either observers or the user says.
     void onSigDialComplete (DialContext *ctx, bool ok);
     //! Invoked when a number dial is completed.
-    void dialComplete (AsyncTaskToken *token);
+    void dialComplete ();
 
     //! Invoked when the user finally clicks on the send SMS button
     void sendSMS (const QStringList &arrNumbers, const QString &strText);
@@ -135,18 +135,7 @@ private slots:
     //! Invoked every time a new registered phone is retrieved
     void gotRegisteredPhone (const GVRegisteredNumber &info);
     //! Invoked every time a new registered phone is retrieved
-    void gotAllRegisteredPhones (AsyncTaskToken *token);
-
-    //! Invoked by the inbox page when a voice mail is to be downloaded
-    void retrieveVoicemail (const QString &strVmailLink);
-    //! Invoked by GVApi when the voice mail download has completed
-    void onVmailDownloaded (AsyncTaskToken *token);
-    //! Invoked when the vmail player changes state
-    void onVmailPlayerStateChanged(Phonon::State newState,
-                                   Phonon::State oldState);
-    //! Invoked when the QML sends us a vmail play/pause/stop signal
-    void onSigVmailPlayback (int newstate);
-    void ensureVmailPlaying();
+    void gotAllRegisteredPhones ();
 
     //! Invoked by QML when the user selects a new phone method
     void onRegPhoneSelectionChange (int index);
@@ -209,11 +198,6 @@ private slots:
     void onSetContactsModel(QAbstractItemModel *model,
                             QAbstractItemModel *searchModel);
 
-    //! Invoked when the vmail is being shut off
-    void onSigCloseVmail();
-    //! Invoked when the vmail player has finished playing
-    void onVmailPlayerFinished();
-
     //! Created to delete the cookie jar and re-create it
     void onRecreateCookieJar();
 
@@ -264,13 +248,14 @@ private:
     void initQML ();
     bool connectSettingsSignals();
 
-
     void initContacts (const QString &contactsPass);
     void deinitContacts ();
 
     void initInbox ();
     void deinitInbox ();
 
+    void logoutWork(AsyncTaskToken *token);
+
     bool findInfo (const QString &strNumber, ContactInfo &info);
 
     bool refreshRegisteredNumbers ();
@@ -278,8 +263,6 @@ private:
                           GVRegisteredNumber   &gvRegNumber,
                           CalloutInitiator    *&initiator  );
 
-    void playVmail (const QString &strFile);
-
     void setUsername(const QString &strUsername);
     void setPassword(const QString &strPassword);
 
@@ -288,8 +271,6 @@ private:
 
     void clearSmsDestinations();
 
-    void createVmailPlayer();
-
     void initMq();
 
     //! Get a pointer to the QML object
@@ -317,10 +298,8 @@ private:
     GVContactsTable *oContacts;
     //! GV Inbox object
     GVInbox         *oInbox;
-
-    bool bBeginPlayAfterLoad;
-    //! The Phonon vmail player
-    Phonon::MediaObject *vmailPlayer;
+    //! Vmail object
+    qgvVmail        *oVmail;
 
     //! The QNAM for the MainWindow. Almost never used except to send logs.
     QNetworkAccessManager *nwMgr;
@@ -371,9 +350,6 @@ private:
     //! The users registered numbers
     GVRegisteredNumberArray arrNumbers;
 
-    //! Map between the voice mail link and its temp file name
-    QMap<QString,QString> mapVmail;
-
     QMutex          logMutex;
     //! This holds a circular buffer of log messages that will be shown by QML
     QStringList     arrLogMsgs;
@@ -408,6 +384,10 @@ private:
     //! of the CI needs to be saved here because the dialog box for the number
     //! is asynchronous
     QString         m_dialoutSelectionId;
+
+    friend class GVInbox;
+    friend class GVContactsTable;
+    friend class qgvVmail;
 };
 
 #endif // MAINWINDOW_H
